package br.com.evologica.mvp.ui.base;

import javax.inject.Inject;

import br.com.evologica.mvp.data.DataManager;
import io.reactivex.disposables.CompositeDisposable;

public class BasePresenter<V extends MvpView> implements MvpPresenter<V> {

    private V mMvpView;

    private final DataManager mDataManager;
    private final CompositeDisposable mCompositeDisposable;

    @Inject
    public BasePresenter(DataManager mDataManager,  CompositeDisposable mCompositeDisposable) {
        this.mDataManager = mDataManager;
        this.mCompositeDisposable = mCompositeDisposable;
    }

    public V getMvpView() {
        return mMvpView;
    }

    @Override
    public void onAttach(V mvpView) {
        mMvpView = mvpView;
    }

    @Override
    public void onDetach() {
        mCompositeDisposable.dispose();
        mMvpView = null;
    }

    public boolean isViewAttached() {
        return mMvpView != null;
    }

    public DataManager getDataManager() {
        return mDataManager;
    }

    public CompositeDisposable getCompositeDisposable() {
        return mCompositeDisposable;
    }

}
