package br.com.evologica.mvp.ui.login;

import javax.inject.Inject;

import br.com.evologica.mvp.data.DataManager;
import br.com.evologica.mvp.ui.base.BasePresenter;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.disposables.CompositeDisposable;
import io.reactivex.schedulers.Schedulers;

/**
 * Created by marcussales on 01/03/2017.
 */

public class LoginPresenter<V extends LoginMvpView> extends BasePresenter<V> implements LoginMvpPresenter<V> {

    private static final String TAG = "LoginPresenter";

    @Inject
    public LoginPresenter(DataManager dataManager, CompositeDisposable compositeDisposable) {
        super(dataManager, compositeDisposable);
    }

    @Override
    public void onLogin(String email, String password) {
        getMvpView().showLoading();
        getCompositeDisposable().add(
                getDataManager().getService().openSession(email, password)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(
                        session -> {
                            getDataManager().setLoggedIn();
                            getMvpView().openMainActivity();
                            getMvpView().hideLoading();
                        },
                        err -> {
                            getDataManager().setLoggedOut();
                            getMvpView().onError(err.getMessage());
                            getMvpView().hideLoading();
                        }

                )
        );
    }
}
