package br.com.evologica.mvp.ui.main;

import javax.inject.Inject;

import br.com.evologica.curio.CurioRequest;
import br.com.evologica.curio.UseCase;
import br.com.evologica.mvp.data.DataManager;
import br.com.evologica.mvp.ui.base.BasePresenter;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.disposables.CompositeDisposable;
import io.reactivex.functions.Function;
import io.reactivex.schedulers.Schedulers;

public class MainPresenter<V extends MainMvpView> extends BasePresenter<V> implements MainMvpPresenter<V> {

    @Inject
    public MainPresenter(DataManager dataManager, CompositeDisposable compositeDisposable) {
        super(dataManager, compositeDisposable);
    }

    @Override
    public void onAttach(V mvpView) {
        super.onAttach(mvpView);
        getMvpView().showLoading();
        getCompositeDisposable().add(
                getDataManager().getService().openUseCase("3034", "ConsultarEventos")
                        .subscribeOn(Schedulers.io())
                        .observeOn(AndroidSchedulers.mainThread())
                        .subscribe(
                                uc -> {
                                    System.out.println("UC Opened");
                                    CurioRequest request = uc.newRequest("RM_BUSCAR_EVENTOS");
                                    request.getMessage().getRootField().addField("Evento");
                                    request.post()
                                            .subscribeOn(Schedulers.io())
                                            .observeOn(AndroidSchedulers.mainThread())
                                            .subscribe(
                                            req -> {
                                                System.out.println("SUCCESS: " + req.getResponse().getRootField().getXMLString());
                                            },
                                            err -> {
                                                System.out.println(err.getMessage());
                                            },
                                            getMvpView()::hideLoading
                                    );
                                },
                                err -> {
                                    getDataManager().setLoggedOut();
                                    getMvpView().openLoginActivity();
                                    System.out.println(err.getMessage());
                                    getMvpView().hideLoading();
                                }

                        )
        );
    }
    @Override
    public void onLogout() {
        getMvpView().showLoading();
        getCompositeDisposable().add(
                getDataManager().getService().closeSession()
                        .subscribeOn(Schedulers.io())
                        .observeOn(AndroidSchedulers.mainThread())
                        .subscribe(
                                result -> {
                                    getDataManager().setLoggedOut();
                                    getMvpView().openLoginActivity();
                                },
                                err -> {
                                    getDataManager().setLoggedOut();
                                    getMvpView().openLoginActivity();
                                    System.out.println(err.toString());
                                },
                                getMvpView()::hideLoading
                        )
        );

    }
}
